pub enum CpuPlacement {
Inherit,
Auto,
Spread,
Compact,
}Expand description
Controls how Microsandbox places vCPU threads on host processors.
Variants
Inherit
Preserve the invoking process’s existing scheduler and affinity behavior.
Auto
Spread across cores, then use SMT siblings, then share logical processors under pressure.
Spread
Preserve the widest practical distribution, sharing logical processors when necessary.
Compact
Prefer SMT siblings and fewer physical cores, then share balanced logical processors.
Implementations
Sourceimpl CpuPlacement
impl CpuPlacement
Sourcepub const fn is_inherit(&self) -> bool
pub const fn is_inherit(&self) -> bool
Returns whether this policy preserves the inherited host placement.