pub enum NamedVolumeMode {
Existing,
Create,
EnsureExists,
}Expand description
Sandbox-time behavior for a named volume mount.
Variants
Existing
Require the named volume to already exist.
Create
Create the named volume and fail if it already exists.
EnsureExists
Ensure the named volume exists, or reuse a compatible existing volume.