pub enum NumaPlacement {
PreferSingle,
StrictSingle,
Inherit,
}Expand description
Concrete host NUMA scope selected by a named placement profile.
Variants
PreferSingle
Prefer one host NUMA node, falling back to inherited host placement when it cannot fit.
StrictSingle
Require maximum CPU and memory capacity to fit one host NUMA node.
Inherit
Preserve the operating system’s ordinary NUMA behavior.