Patch

Enum Patch 

pub enum Patch {
    Text {
        path: String,
        content: String,
        mode: Option<u32>,
        replace: bool,
    },
    File {
        path: String,
        content: Vec<u8>,
        mode: Option<u32>,
        replace: bool,
    },
    CopyFile {
        src: PathBuf,
        dst: String,
        mode: Option<u32>,
        replace: bool,
    },
    CopyDir {
        src: PathBuf,
        dst: String,
        replace: bool,
    },
    Symlink {
        target: String,
        link: String,
        replace: bool,
    },
    Mkdir {
        path: String,
        mode: Option<u32>,
    },
    Remove {
        path: String,
    },
    Append {
        path: String,
        content: String,
    },
}
Rootfs patch applied before VM startup.

Variants



Text

Write text content to a file.

Fields

path: String

Absolute guest path, such as /etc/app.conf.

content: String

Text content to write.

mode: Option<u32>

File permissions, such as 0o644. None uses the default.

replace: bool

Allow replacing a file that already exists in the rootfs.



File

Write raw bytes to a file.

Fields

path: String

Absolute guest path.

content: Vec<u8>

Raw byte content to write.

mode: Option<u32>

File permissions, such as 0o644. None uses the default.

replace: bool

Allow replacing a file that already exists in the rootfs.



CopyFile

Copy a file from the host into the rootfs.

Fields

src: PathBuf

Host path to copy from.

dst: String

Absolute guest destination path.

mode: Option<u32>

File permissions. None preserves source permissions.

replace: bool

Allow replacing a file that already exists in the rootfs.



CopyDir

Copy a directory from the host into the rootfs.

Fields

src: PathBuf

Host directory to copy from.

dst: String

Absolute guest destination path.

replace: bool

Allow replacing files that already exist in the rootfs.

Create a symlink.

Fields

target: String

Symlink target path.

link: String

Absolute guest path where the symlink is created.

replace: bool

Allow replacing a path that already exists in the rootfs.



Mkdir

Create a directory.

Fields

path: String

Absolute guest path.

mode: Option<u32>

Directory permissions, such as 0o755. None uses the default.



Remove

Remove a file or directory.

Fields

path: String

Absolute guest path to remove.



Append

Append content to an existing file.

Fields

path: String

Absolute guest path of the file to append to.

content: String

Content to append.