pub enum ModificationDisposition {
Live,
NextStart,
RequiresRestart,
Unsupported,
}Expand description
When or whether a planned change can take effect.
Variants
Live
Applies to the running VM now.
NextStart
Persists to desired config and applies the next time the sandbox starts.
RequiresRestart
Needs a restart before it can take effect.
Unsupported
Cannot be changed by modify.