pub struct HandoffInit {
pub cmd: PathBuf,
pub args: Vec<String>,
pub env: Vec<(String, String)>,
}Expand description
Fully-assembled handoff-init specification.
Fields
cmd: PathBufInit binary: absolute path inside the guest rootfs, or the literal auto.
args: Vec<String>Supplemental argv. argv[0] is implicitly cmd.
env: Vec<(String, String)>Extra env vars merged on top of the inherited env.