pub enum Patch {
Text {
path: String,
content: String,
mode: Option<u32>,
replace: bool,
},
File {
path: String,
content: Vec<u8>,
mode: Option<u32>,
replace: bool,
},
CopyFile {
src: PathBuf,
dst: String,
mode: Option<u32>,
replace: bool,
},
CopyDir {
src: PathBuf,
dst: String,
replace: bool,
},
Symlink {
target: String,
link: String,
replace: bool,
},
Mkdir {
path: String,
mode: Option<u32>,
},
Remove {
path: String,
},
Append {
path: String,
content: String,
},
}Expand description
Rootfs patch applied before VM startup.
Variants
Text
Write text content to a file.
Fields
File
Write raw bytes to a file.
Fields
CopyFile
Copy a file from the host into the rootfs.
Fields
CopyDir
Copy a directory from the host into the rootfs.
Fields
Symlink
Create a symlink.
Fields
Mkdir
Create a directory.
Fields
Remove
Remove a file or directory.
Append
Append content to an existing file.