RootfsSource

Enum RootfsSource 

pub enum RootfsSource {
    Bind(PathBuf),
    Oci(OciRootfsSource),
    DiskImage {
        path: PathBuf,
        format: DiskImageFormat,
        fstype: Option<String>,
    },
}
Root filesystem source for a sandbox.

Variants



Bind(PathBuf)

Use a host directory directly as the root filesystem.

Tuple Fields

0: PathBuf

Host path to bind mount.



Oci(OciRootfsSource)

Use an OCI image reference with an EROFS lower and ext4 overlay upper.



DiskImage

Use a disk image file as the root filesystem via virtio-blk.

Fields

path: PathBuf

Path to the disk image file on the host.

format: DiskImageFormat

Disk image format.

fstype: Option<String>

Inner filesystem type (optional; auto-detected if absent).

Implementations

Source

impl RootfsSource

pub fn oci(reference: impl Into<String>) -> Self

Create an OCI rootfs source from an image reference.

pub fn oci_reference(&self) -> Option<&str>

Return the OCI image reference if this is an OCI rootfs.

pub fn oci_upper_size_mib(&self) -> Option<u32>

Return the configured OCI upper size in MiB if this is an OCI rootfs.