pub struct SandboxRuntimeOptionsPatch { /* private fields */ }Expand description
A sparse, presence-aware patch for SandboxRuntimeOptions.
Implementations
Sourceimpl SandboxRuntimeOptionsPatch
impl SandboxRuntimeOptionsPatch
Sourcepub fn scripts(self, value: BTreeMap<String, String>) -> Self
pub fn scripts(self, value: BTreeMap<String, String>) -> Self
Merge value into the scripts field.
Sourcepub fn entrypoint(self, value: Vec<String>) -> Self
pub fn entrypoint(self, value: Vec<String>) -> Self
Set the entrypoint field in this patch.
Sourcepub fn log_level(self, value: SandboxLogLevel) -> Self
pub fn log_level(self, value: SandboxLogLevel) -> Self
Set the log_level field in this patch.
Sourcepub fn metrics_sample_interval_ms(self, value: u64) -> Self
pub fn metrics_sample_interval_ms(self, value: u64) -> Self
Set the metrics_sample_interval_ms field in this patch.
Sourcepub fn disable_metrics_sample(self, value: bool) -> Self
pub fn disable_metrics_sample(self, value: bool) -> Self
Set the disable_metrics_sample field in this patch.
Sourcepub fn replace_scripts(self, value: BTreeMap<String, String>) -> Self
pub fn replace_scripts(self, value: BTreeMap<String, String>) -> Self
Replace the complete scripts field.
Sourcepub fn clear_workdir(self) -> Self
pub fn clear_workdir(self) -> Self
Remove workdir from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_shell(self) -> Self
pub fn clear_shell(self) -> Self
Remove shell from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_scripts(self) -> Self
pub fn clear_scripts(self) -> Self
Remove scripts from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_entrypoint(self) -> Self
pub fn clear_entrypoint(self) -> Self
Remove entrypoint from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_cmd(self) -> Self
pub fn clear_cmd(self) -> Self
Remove cmd from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_hostname(self) -> Self
pub fn clear_hostname(self) -> Self
Remove hostname from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_user(self) -> Self
pub fn clear_user(self) -> Self
Remove user from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_log_level(self) -> Self
pub fn clear_log_level(self) -> Self
Remove log_level from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_metrics_sample_interval_ms(self) -> Self
pub fn clear_metrics_sample_interval_ms(self) -> Self
Remove metrics_sample_interval_ms from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_disable_metrics_sample(self) -> Self
pub fn clear_disable_metrics_sample(self) -> Self
Remove disable_metrics_sample from this patch so applying it leaves the target unchanged.
Sourcepub fn overlay(self, higher: Self) -> Self
pub fn overlay(self, higher: Self) -> Self
Overlay a higher-precedence patch using each field’s declared strategy.
Sourcepub fn apply_to(self, target: &mut SandboxRuntimeOptions)
pub fn apply_to(self, target: &mut SandboxRuntimeOptions)
Apply every present field to an existing value.
Sourcepub fn from_present_fields(value: SandboxRuntimeOptions) -> Self
pub fn from_present_fields(value: SandboxRuntimeOptions) -> Self
Convert non-null fields into a changeset, treating Option::None as absent.