pub struct TlsConfigPatch {
pub enabled: Option<bool>,
pub intercepted_ports: Option<Vec<u16>>,
pub bypass: Option<Vec<String>>,
pub verify_upstream: Option<bool>,
pub block_quic_on_intercept: Option<bool>,
pub upstream_ca_cert: Option<Vec<PathBuf>>,
pub scoped_upstream_ca_cert: Option<Vec<ScopedUpstreamCaCert>>,
pub scoped_verify_upstream: Option<Vec<ScopedVerifyUpstream>>,
pub intercept_ca: Option<InterceptCaConfig>,
pub cache: Option<CertCacheConfig>,
}Expand description
A sparse, presence-aware patch for TlsConfig.
Fields
enabled: Option<bool>Pending update for enabled. Omitted values leave the target unchanged.
intercepted_ports: Option<Vec<u16>>Pending update for intercepted_ports. Omitted values leave the target unchanged.
bypass: Option<Vec<String>>Pending update for bypass. Omitted values leave the target unchanged.
verify_upstream: Option<bool>Pending update for verify_upstream. Omitted values leave the target unchanged.
block_quic_on_intercept: Option<bool>Pending update for block_quic_on_intercept. Omitted values leave the target unchanged.
upstream_ca_cert: Option<Vec<PathBuf>>Pending update for upstream_ca_cert. Omitted values leave the target unchanged.
scoped_upstream_ca_cert: Option<Vec<ScopedUpstreamCaCert>>Pending update for scoped_upstream_ca_cert. Omitted values leave the target unchanged.
scoped_verify_upstream: Option<Vec<ScopedVerifyUpstream>>Pending update for scoped_verify_upstream. Omitted values leave the target unchanged.
intercept_ca: Option<InterceptCaConfig>Pending update for intercept_ca. Omitted values leave the target unchanged.
cache: Option<CertCacheConfig>Pending update for cache. Omitted values leave the target unchanged.
Implementations
Sourceimpl TlsConfigPatch
impl TlsConfigPatch
Sourcepub fn enabled_mut(&mut self, value: bool) -> &mut Self
pub fn enabled_mut(&mut self, value: bool) -> &mut Self
Set the enabled field in this patch.
Mutates this patch in place and returns it for chaining.
Sourcepub fn intercepted_ports(self, value: Vec<u16>) -> Self
pub fn intercepted_ports(self, value: Vec<u16>) -> Self
Set the intercepted_ports field in this patch.
Sourcepub fn intercepted_ports_mut(&mut self, value: Vec<u16>) -> &mut Self
pub fn intercepted_ports_mut(&mut self, value: Vec<u16>) -> &mut Self
Set the intercepted_ports field in this patch.
Mutates this patch in place and returns it for chaining.
Sourcepub fn bypass_mut(&mut self, value: Vec<String>) -> &mut Self
pub fn bypass_mut(&mut self, value: Vec<String>) -> &mut Self
Set the bypass field in this patch.
Mutates this patch in place and returns it for chaining.
Sourcepub fn verify_upstream(self, value: bool) -> Self
pub fn verify_upstream(self, value: bool) -> Self
Set the verify_upstream field in this patch.
Sourcepub fn verify_upstream_mut(&mut self, value: bool) -> &mut Self
pub fn verify_upstream_mut(&mut self, value: bool) -> &mut Self
Set the verify_upstream field in this patch.
Mutates this patch in place and returns it for chaining.
Sourcepub fn block_quic_on_intercept(self, value: bool) -> Self
pub fn block_quic_on_intercept(self, value: bool) -> Self
Set the block_quic_on_intercept field in this patch.
Sourcepub fn block_quic_on_intercept_mut(&mut self, value: bool) -> &mut Self
pub fn block_quic_on_intercept_mut(&mut self, value: bool) -> &mut Self
Set the block_quic_on_intercept field in this patch.
Mutates this patch in place and returns it for chaining.
Sourcepub fn upstream_ca_cert(self, value: Vec<PathBuf>) -> Self
pub fn upstream_ca_cert(self, value: Vec<PathBuf>) -> Self
Set the upstream_ca_cert field in this patch.
Sourcepub fn upstream_ca_cert_mut(&mut self, value: Vec<PathBuf>) -> &mut Self
pub fn upstream_ca_cert_mut(&mut self, value: Vec<PathBuf>) -> &mut Self
Set the upstream_ca_cert field in this patch.
Mutates this patch in place and returns it for chaining.
Sourcepub fn scoped_upstream_ca_cert(self, value: Vec<ScopedUpstreamCaCert>) -> Self
pub fn scoped_upstream_ca_cert(self, value: Vec<ScopedUpstreamCaCert>) -> Self
Set the scoped_upstream_ca_cert field in this patch.
Sourcepub fn scoped_upstream_ca_cert_mut(
&mut self,
value: Vec<ScopedUpstreamCaCert>,
) -> &mut Self
pub fn scoped_upstream_ca_cert_mut( &mut self, value: Vec<ScopedUpstreamCaCert>, ) -> &mut Self
Set the scoped_upstream_ca_cert field in this patch.
Mutates this patch in place and returns it for chaining.
Sourcepub fn scoped_verify_upstream(self, value: Vec<ScopedVerifyUpstream>) -> Self
pub fn scoped_verify_upstream(self, value: Vec<ScopedVerifyUpstream>) -> Self
Set the scoped_verify_upstream field in this patch.
Sourcepub fn scoped_verify_upstream_mut(
&mut self,
value: Vec<ScopedVerifyUpstream>,
) -> &mut Self
pub fn scoped_verify_upstream_mut( &mut self, value: Vec<ScopedVerifyUpstream>, ) -> &mut Self
Set the scoped_verify_upstream field in this patch.
Mutates this patch in place and returns it for chaining.
Sourcepub fn intercept_ca(self, value: InterceptCaConfig) -> Self
pub fn intercept_ca(self, value: InterceptCaConfig) -> Self
Set the intercept_ca field in this patch.
Sourcepub fn intercept_ca_mut(&mut self, value: InterceptCaConfig) -> &mut Self
pub fn intercept_ca_mut(&mut self, value: InterceptCaConfig) -> &mut Self
Set the intercept_ca field in this patch.
Mutates this patch in place and returns it for chaining.
Sourcepub fn cache(self, value: CertCacheConfig) -> Self
pub fn cache(self, value: CertCacheConfig) -> Self
Set the cache field in this patch.
Sourcepub fn cache_mut(&mut self, value: CertCacheConfig) -> &mut Self
pub fn cache_mut(&mut self, value: CertCacheConfig) -> &mut Self
Set the cache field in this patch.
Mutates this patch in place and returns it for chaining.
Sourcepub fn clear_enabled(self) -> Self
pub fn clear_enabled(self) -> Self
Remove enabled from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_enabled_mut(&mut self) -> &mut Self
pub fn clear_enabled_mut(&mut self) -> &mut Self
Remove enabled from this patch so applying it leaves the target unchanged.
Mutates this patch in place and returns it for chaining.
Sourcepub fn clear_intercepted_ports(self) -> Self
pub fn clear_intercepted_ports(self) -> Self
Remove intercepted_ports from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_intercepted_ports_mut(&mut self) -> &mut Self
pub fn clear_intercepted_ports_mut(&mut self) -> &mut Self
Remove intercepted_ports from this patch so applying it leaves the target unchanged.
Mutates this patch in place and returns it for chaining.
Sourcepub fn clear_bypass(self) -> Self
pub fn clear_bypass(self) -> Self
Remove bypass from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_bypass_mut(&mut self) -> &mut Self
pub fn clear_bypass_mut(&mut self) -> &mut Self
Remove bypass from this patch so applying it leaves the target unchanged.
Mutates this patch in place and returns it for chaining.
Sourcepub fn clear_verify_upstream(self) -> Self
pub fn clear_verify_upstream(self) -> Self
Remove verify_upstream from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_verify_upstream_mut(&mut self) -> &mut Self
pub fn clear_verify_upstream_mut(&mut self) -> &mut Self
Remove verify_upstream from this patch so applying it leaves the target unchanged.
Mutates this patch in place and returns it for chaining.
Sourcepub fn clear_block_quic_on_intercept(self) -> Self
pub fn clear_block_quic_on_intercept(self) -> Self
Remove block_quic_on_intercept from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_block_quic_on_intercept_mut(&mut self) -> &mut Self
pub fn clear_block_quic_on_intercept_mut(&mut self) -> &mut Self
Remove block_quic_on_intercept from this patch so applying it leaves the target unchanged.
Mutates this patch in place and returns it for chaining.
Sourcepub fn clear_upstream_ca_cert(self) -> Self
pub fn clear_upstream_ca_cert(self) -> Self
Remove upstream_ca_cert from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_upstream_ca_cert_mut(&mut self) -> &mut Self
pub fn clear_upstream_ca_cert_mut(&mut self) -> &mut Self
Remove upstream_ca_cert from this patch so applying it leaves the target unchanged.
Mutates this patch in place and returns it for chaining.
Sourcepub fn clear_scoped_upstream_ca_cert(self) -> Self
pub fn clear_scoped_upstream_ca_cert(self) -> Self
Remove scoped_upstream_ca_cert from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_scoped_upstream_ca_cert_mut(&mut self) -> &mut Self
pub fn clear_scoped_upstream_ca_cert_mut(&mut self) -> &mut Self
Remove scoped_upstream_ca_cert from this patch so applying it leaves the target unchanged.
Mutates this patch in place and returns it for chaining.
Sourcepub fn clear_scoped_verify_upstream(self) -> Self
pub fn clear_scoped_verify_upstream(self) -> Self
Remove scoped_verify_upstream from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_scoped_verify_upstream_mut(&mut self) -> &mut Self
pub fn clear_scoped_verify_upstream_mut(&mut self) -> &mut Self
Remove scoped_verify_upstream from this patch so applying it leaves the target unchanged.
Mutates this patch in place and returns it for chaining.
Sourcepub fn clear_intercept_ca(self) -> Self
pub fn clear_intercept_ca(self) -> Self
Remove intercept_ca from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_intercept_ca_mut(&mut self) -> &mut Self
pub fn clear_intercept_ca_mut(&mut self) -> &mut Self
Remove intercept_ca from this patch so applying it leaves the target unchanged.
Mutates this patch in place and returns it for chaining.
Sourcepub fn clear_cache(self) -> Self
pub fn clear_cache(self) -> Self
Remove cache from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_cache_mut(&mut self) -> &mut Self
pub fn clear_cache_mut(&mut self) -> &mut Self
Remove cache from this patch so applying it leaves the target unchanged.
Mutates this patch in place and returns it for chaining.
Sourcepub fn overlay(self, higher: Self) -> Self
pub fn overlay(self, higher: Self) -> Self
Overlay a higher-precedence patch using each field’s declared strategy.
Sourcepub fn overlay_mut(&mut self, higher: Self) -> &mut Self
pub fn overlay_mut(&mut self, higher: Self) -> &mut Self
Overlay a higher-precedence patch using each field’s declared strategy. Mutates this patch in place and returns it for chaining.
Sourcepub fn into_config(self) -> TlsConfig
pub fn into_config(self) -> TlsConfig
Apply this patch to the configuration’s defaults.
Compose all overlays first. This conversion does not validate the result.
Sourcepub fn from_present_fields(value: TlsConfig) -> Self
pub fn from_present_fields(value: TlsConfig) -> Self
Convert non-null fields into a changeset, treating Option::None as absent.