pub struct TlsConfigPatch { /* private fields */ }Expand description
A sparse, presence-aware patch for TlsConfig.
Implementations
Sourceimpl TlsConfigPatch
impl TlsConfigPatch
Sourcepub fn intercepted_ports(self, value: Vec<u16>) -> Self
pub fn intercepted_ports(self, value: Vec<u16>) -> Self
Set the intercepted_ports field in this patch.
Sourcepub fn verify_upstream(self, value: bool) -> Self
pub fn verify_upstream(self, value: bool) -> Self
Set the verify_upstream field in this patch.
Sourcepub fn block_quic_on_intercept(self, value: bool) -> Self
pub fn block_quic_on_intercept(self, value: bool) -> Self
Set the block_quic_on_intercept field in this patch.
Sourcepub fn upstream_ca_cert(self, value: Vec<PathBuf>) -> Self
pub fn upstream_ca_cert(self, value: Vec<PathBuf>) -> Self
Set the upstream_ca_cert field in this patch.
Sourcepub fn scoped_upstream_ca_cert(self, value: Vec<ScopedUpstreamCaCert>) -> Self
pub fn scoped_upstream_ca_cert(self, value: Vec<ScopedUpstreamCaCert>) -> Self
Set the scoped_upstream_ca_cert field in this patch.
Sourcepub fn scoped_verify_upstream(self, value: Vec<ScopedVerifyUpstream>) -> Self
pub fn scoped_verify_upstream(self, value: Vec<ScopedVerifyUpstream>) -> Self
Set the scoped_verify_upstream field in this patch.
Sourcepub fn intercept_ca(self, value: InterceptCaConfig) -> Self
pub fn intercept_ca(self, value: InterceptCaConfig) -> Self
Set the intercept_ca field in this patch.
Sourcepub fn cache(self, value: CertCacheConfig) -> Self
pub fn cache(self, value: CertCacheConfig) -> Self
Set the cache field in this patch.
Sourcepub fn clear_enabled(self) -> Self
pub fn clear_enabled(self) -> Self
Remove enabled from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_intercepted_ports(self) -> Self
pub fn clear_intercepted_ports(self) -> Self
Remove intercepted_ports from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_bypass(self) -> Self
pub fn clear_bypass(self) -> Self
Remove bypass from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_verify_upstream(self) -> Self
pub fn clear_verify_upstream(self) -> Self
Remove verify_upstream from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_block_quic_on_intercept(self) -> Self
pub fn clear_block_quic_on_intercept(self) -> Self
Remove block_quic_on_intercept from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_upstream_ca_cert(self) -> Self
pub fn clear_upstream_ca_cert(self) -> Self
Remove upstream_ca_cert from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_scoped_upstream_ca_cert(self) -> Self
pub fn clear_scoped_upstream_ca_cert(self) -> Self
Remove scoped_upstream_ca_cert from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_scoped_verify_upstream(self) -> Self
pub fn clear_scoped_verify_upstream(self) -> Self
Remove scoped_verify_upstream from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_intercept_ca(self) -> Self
pub fn clear_intercept_ca(self) -> Self
Remove intercept_ca from this patch so applying it leaves the target unchanged.
Sourcepub fn clear_cache(self) -> Self
pub fn clear_cache(self) -> Self
Remove cache from this patch so applying it leaves the target unchanged.
Sourcepub fn overlay(self, higher: Self) -> Self
pub fn overlay(self, higher: Self) -> Self
Overlay a higher-precedence patch using each field’s declared strategy.
Sourcepub fn from_present_fields(value: TlsConfig) -> Self
pub fn from_present_fields(value: TlsConfig) -> Self
Convert non-null fields into a changeset, treating Option::None as absent.